Core Stingray Functionality
***************************

Here we show how many of the core Stingray classes and methods 
work in practice. We start with basic data constructs for 
event data and light curve data, and then show how to produce 
various Fourier products from these data sets.

Working with Event Data
=======================

.. toctree::
   :maxdepth: 2

   notebooks/EventList/EventList Tutorial.ipynb

Working with Lightcurves
========================

.. toctree::
   :maxdepth: 2

   notebooks/Lightcurve/Lightcurve tutorial.ipynb
   notebooks/Lightcurve/Analyze light curves chunk by chunk - an example.ipynb

Fourier Analysis
================

Powerspectra
------------

.. toctree::
   :maxdepth: 2

   notebooks/Powerspectrum/Powerspectrum_tutorial.ipynb

Dynamical Power Spectra
-----------------------

.. toctree::
   :maxdepth: 2

   notebooks/DynamicalPowerspectrum/DynamicalPowerspectrum_tutorial_[fake_data].ipynb
   notebooks/DynamicalPowerspectrum/DynamicalPowerspectrum_tutorial_[real_data].ipynb

Cross Spectra
-------------

.. toctree::
   :maxdepth: 2

   notebooks/Crossspectrum/Crossspectrum_tutorial.ipynb

Cross- and Autocorrelations
---------------------------

.. toctree::
   :maxdepth: 2

   notebooks/CrossCorrelation/cross_correlation_notebook.ipynb


Bispectra
---------

.. toctree::
   :maxdepth: 2

   notebooks/Bispectrum/bispectrum_tutorial.ipynb


